# Changelog

All notable changes to this project will be documented in this file.

This changelog should be updated with every pull request with some information about what has been changed. These changes can be added under a temporary title 'pre-release'.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).
Each release can have sections: "Added", "Changed", "Deprecated", "Removed", "Fixed" and "Security".

## pre-release

### Added

- types, docstrings and comments

### Changed

- improved readme
- renamed to gnssir-rt

## [1.1.0] - 2025-03-04

### Changed

- using ruff instead of flake8, isort etc. for linting

### Removed

- poetry for packaging